# Copyright 2021 Max Beinlich

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from enum import Enum

class MarketState(Enum):
    """
    The MarketState shows what state the instruments market currently assumes.

    Notice that this does not include a "CLOSED" market state. This is because 
    quotes are not emitted when the underlying market is closed / when no 
    trading occures.

    Depending on the MarketState quotes might be less frequent / delayed.
    """

    PRE         = 0
    REGULAR     = 1
    POST        = 2
    EXTENDED    = 3
    NONE        = None