# Copyright 2021 Max Beinlich

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from enum import Enum

class OptionType(Enum):
    """
    The type of option, if quoteType is OPTION.

    If a quote assumes the type OPTION, the OptionType should either be CALL or
    PUT. The OptionType defaults to OptionType.NONE.
    """

    CALL    = 0
    PUT     = 1
    NONE    = None